from imodelsx import EmbGAMClassifier
import datasets
import numpy as np

if __name__ == '__main__':
    # set up data
    dset = datasets.load_dataset('rotten_tomatoes')['train']
    dset = dset.select(np.random.choice(len(dset), size=10, replace=False))
    dset_val = datasets.load_dataset('rotten_tomatoes')['validation']
    dset_val = dset_val.select(np.random.choice(len(dset_val), size=10, replace=False))

    # fit model
    m = EmbGAMClassifier(
        checkpoint='textattack/distilbert-base-uncased-rotten-tomatoes',
        ngrams=2,
        all_ngrams=True, # also use lower-order ngrams
    )
    m.fit(dset['text'], dset['label'])

    # predict
    preds = m.predict(dset_val['text'])
    print('acc_val', np.mean(preds == dset_val['label']))

    # interpret
    print('Total ngram coefficients: ', len(m.coefs_dict_))
    print('Most positive ngrams')
    for k, v in sorted(m.coefs_dict_.items(), key=lambda item: item[1], reverse=True)[:8]:
        print('\t', k, round(v, 2))
    print('Most negative ngrams')
    for k, v in sorted(m.coefs_dict_.items(), key=lambda item: item[1])[:8]:
        print('\t', k, round(v, 2))

    print('successfully ran!')
